from django.contrib import admin
from django.contrib.auth.admin import UserAdmin
from .models import CustomUser


class CustomUserAdmin(UserAdmin):
    model = CustomUser
    list_display = ('email', 'name', 'grade', 'is_active', 'is_staff')
    list_filter = ('grade', 'is_active', 'is_staff')
    search_fields = ('email', 'name')
    ordering = ('email',)

    readonly_fields = ('created_at',)

    fieldsets = (
        (None, {'fields': ('email', 'password')}),
        ('Personal Info', {'fields': ('name', 'grade')}),
        ('Permissions', {'fields': ('is_active', 'is_staff', 'is_superuser', 'groups', 'user_permissions')}),
        ('Important dates', {'fields': ('last_login', 'created_at')}),
    )

    add_fieldsets = (
        (None, {
            'classes': ('wide',),
            'fields': ('email', 'name', 'grade', 'password1', 'password2', 'is_active', 'is_staff', 'is_superuser')}
        ),
    )


admin.site.register(CustomUser, CustomUserAdmin)
